"ssn_range" needs to be a copy of "global_ssn_range", so that it's not
[obnox/wireshark/wip.git] / print.h
diff --git a/print.h b/print.h
index d2b97bce3bcd295f618240c09b1d4975ed6bf93b..a0871fb47b2060be9ba3fc3e4dbb831c7335c897 100644 (file)
--- a/print.h
+++ b/print.h
@@ -1,7 +1,7 @@
 /* print.h
  * Definitions for printing packet analysis trees.
  *
- * $Id: print.h,v 1.38 2004/04/15 19:56:15 ulfl Exp $
+ * $Id$
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
 
 #include <epan/packet.h>
 
-#define PR_FMT_TEXT 0
-#define PR_FMT_PS   1
-#define PR_FMT_PDML 2
+#include "packet-range.h"
+
+/*
+ * Print stream code; this provides a "print stream" class with subclasses
+ * of various sorts.  Additional subclasses might be implemented elsewhere.
+ */
+struct print_stream;
+
+typedef struct print_stream_ops {
+       gboolean (*print_preamble)(struct print_stream *self, gchar *filename);
+       gboolean (*print_line)(struct print_stream *self, int indent,
+           const char *line);
+       gboolean (*print_bookmark)(struct print_stream *self,
+           const gchar *name, const gchar *title);
+       gboolean (*new_page)(struct print_stream *self);
+       gboolean (*print_finale)(struct print_stream *self);
+       gboolean (*destroy)(struct print_stream *self);
+} print_stream_ops_t;
+
+typedef struct print_stream {
+       const print_stream_ops_t *ops;
+       void *data;
+} print_stream_t;
+
+extern print_stream_t *print_stream_text_new(int to_file, const char *dest);
+extern print_stream_t *print_stream_text_stdio_new(FILE *fh);
+extern print_stream_t *print_stream_ps_new(int to_file, const char *dest);
+extern print_stream_t *print_stream_ps_stdio_new(FILE *fh);
+
+extern gboolean print_preamble(print_stream_t *self, gchar *filename);
+extern gboolean print_line(print_stream_t *self, int indent, const char *line);
+extern gboolean print_bookmark(print_stream_t *self, const gchar *name,
+    const gchar *title);
+extern gboolean new_page(print_stream_t *self);
+extern gboolean print_finale(print_stream_t *self);
+extern gboolean destroy_print_stream(print_stream_t *self);
+
+/* print output format */
+typedef enum {
+  PR_FMT_TEXT,    /* plain text */
+  PR_FMT_PS       /* postscript */
+} print_format_e;
 
 /* print_range, enum which frames should be printed */
 typedef enum {
@@ -50,10 +89,11 @@ typedef enum {
 } print_dissections_e;
 
 typedef struct {
-  gint         format;         /* plain text, PostScript or PDML */
+  print_stream_t *stream;      /* the stream to which we're printing */
+  print_format_e format;       /* plain text or PostScript */
   gboolean     to_file;        /* TRUE if we're printing to a file */
-  char         *dest;          /* if printing to file, pathname;
-                                  if not, command string */
+  char         *file;          /* file output pathname */
+  char         *cmd;           /* print command string (not win32) */
   packet_range_t range;
 
   gboolean     print_summary;  /* TRUE if we should just print summary;
@@ -61,17 +101,24 @@ typedef struct {
   print_dissections_e   print_dissections;
   gboolean     print_hex;      /* TRUE if we should also print hex data;
                                   FALSE if we should print only if not dissected. */
+  gboolean     print_formfeed; /* TRUE if a formfeed should be printed 
+                   before each new packet */
 } print_args_t;
 
-/* Functions in print.h */
+/*
+ * Higher-level packet-printing code.
+ */
+
+extern gboolean proto_tree_print(print_args_t *print_args, epan_dissect_t *edt,
+     print_stream_t *stream);
+extern gboolean print_hex_data(print_stream_t *stream, epan_dissect_t *edt);
+
+extern void write_pdml_preamble(FILE *fh);
+extern void proto_tree_write_pdml(epan_dissect_t *edt, FILE *fh);
+extern void write_pdml_finale(FILE *fh);
 
-FILE *open_print_dest(int to_file, const char *dest);
-gboolean close_print_dest(int to_file, FILE *fh);
-void print_preamble(FILE *fh, gint format);
-void print_finale(FILE *fh, gint format);
-void proto_tree_print(print_args_t *print_args, epan_dissect_t *edt,
-    FILE *fh);
-void print_hex_data(FILE *fh, gint format, epan_dissect_t *edt);
-void print_line(FILE *fh, int indent, gint format, char *line);
+extern void write_psml_preamble(FILE *fh);
+extern void proto_tree_write_psml(epan_dissect_t *edt, FILE *fh);
+extern void write_psml_finale(FILE *fh);
 
 #endif /* print.h */